This is an example .env file for secret information.
It should be manually added to then machine where your
project is deployed. 
Never commit files like this to your public repo. 

Note that the ENVIRONMENT value must be set in your .env
file for the FlaskConfig to work as expected.